@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '2.011';
+our $VERSION = '2.012';
 $VERSION = eval $VERSION;
 
 require WWW::Shorten::_dead;
@@ -32,7 +32,9 @@ Dave Cross C<davecross@cpan.org>
 
 =over
 
-=item Chase Whitener C<capoeirab@cpan.org> -- current maintainer
+=item *
+
+Chase Whitener C<capoeirab@cpan.org>
 
 =back
 
